summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/indi
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/indi')
-rw-r--r--kstars/kstars/indi/apmount.cpp4
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera.cpp124
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera.h14
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera_Linux.cpp4
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera_NET.cpp6
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera_NET.h2
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera_USB.cpp8
-rw-r--r--kstars/kstars/indi/apogee/ApnCamera_USB.h2
-rw-r--r--kstars/kstars/indi/apogee/Apogee.h64
-rw-r--r--kstars/kstars/indi/apogee/ApogeeIoctl.h2
-rw-r--r--kstars/kstars/indi/apogee/ApogeeUsb.h2
-rw-r--r--kstars/kstars/indi/apogee/ApogeeUsbLinux.cpp14
-rw-r--r--kstars/kstars/indi/apogee/ApogeeUsbLinuxForKernel.cpp14
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_Linux.cpp88
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_Linux.h24
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_LinuxISA.cpp8
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_LinuxPCI.cpp8
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_LinuxPPI.cpp8
-rw-r--r--kstars/kstars/indi/apogee/CameraIO_PCI.cpp6
-rw-r--r--kstars/kstars/indi/apogee/Camera_Example.cpp22
-rw-r--r--kstars/kstars/indi/apogee_ppi.cpp38
-rw-r--r--kstars/kstars/indi/celestronprotocol.h2
-rw-r--r--kstars/kstars/indi/fitsrw.c16
-rw-r--r--kstars/kstars/indi/fitsrw.h4
-rw-r--r--kstars/kstars/indi/fli/libfli.c8
-rw-r--r--kstars/kstars/indi/fli/libfli.h2
-rw-r--r--kstars/kstars/indi/fli_ccd.c6
-rw-r--r--kstars/kstars/indi/indiserver.c2
-rw-r--r--kstars/kstars/indi/lilxml.c2
-rw-r--r--kstars/kstars/indi/lx200_16.cpp28
-rw-r--r--kstars/kstars/indi/lx200driver.c16
-rw-r--r--kstars/kstars/indi/lx200driver.h6
-rw-r--r--kstars/kstars/indi/lx200generic.cpp6
-rw-r--r--kstars/kstars/indi/lx200gps.cpp24
-rw-r--r--kstars/kstars/indi/sbigccd.cpp8
-rw-r--r--kstars/kstars/indi/webcam/ccvt.h2
-rw-r--r--kstars/kstars/indi/webcam/ccvt_c2.c2
-rw-r--r--kstars/kstars/indi/webcam/ccvt_misc.c4
-rw-r--r--kstars/kstars/indi/webcam/pwc-ioctl.h2
-rw-r--r--kstars/kstars/indi/webcam/videodev.h2
40 files changed, 302 insertions, 302 deletions
diff --git a/kstars/kstars/indi/apmount.cpp b/kstars/kstars/indi/apmount.cpp
index 781e2a07..d1c05b66 100644
--- a/kstars/kstars/indi/apmount.cpp
+++ b/kstars/kstars/indi/apmount.cpp
@@ -728,9 +728,9 @@ void APMount::ISNewSwitch (const char *dev, const char *name, ISState *states, c
IUUpdateSwitches(&AlignmentSP, states, names, n);
index = getOnSwitch(&AlignmentSP);
- if ( ( err = tqsetAlignmentMode(index) < 0) )
+ if ( ( err = setAlignmentMode(index) < 0) )
{
- handleError(&AlignmentSP, err, "Setting tqalignment");
+ handleError(&AlignmentSP, err, "Setting alignment");
return;
}
diff --git a/kstars/kstars/indi/apogee/ApnCamera.h b/kstars/kstars/indi/apogee/ApnCamera.h
index f1fbef49..b0e6af03 100644
--- a/kstars/kstars/indi/apogee/ApnCamera.h
+++ b/kstars/kstars/indi/apogee/ApnCamera.h
@@ -83,7 +83,7 @@ public:
unsigned short val[],
unsigned short count );
- long QuerytqStatusRegs( unsigned short& tqStatusReg,
+ long QueryStatusRegs( unsigned short& StatusReg,
unsigned short& HeatsinkTempReg,
unsigned short& CcdTempReg,
unsigned short& CoolerDriveReg,
@@ -129,7 +129,7 @@ public:
void write_DataBits( Apn_Resolution BitResolution );
- Apn_tqStatus read_ImagingtqStatus();
+ Apn_Status read_ImagingStatus();
Apn_LedMode read_LedMode();
void write_LedMode( Apn_LedMode LedMode );
@@ -138,7 +138,7 @@ public:
bool read_CoolerEnable();
void write_CoolerEnable( bool CoolerEnable );
- Apn_CoolertqStatus read_CoolertqStatus();
+ Apn_CoolerStatus read_CoolerStatus();
double read_CoolerSetPoint();
void write_CoolerSetPoint( double SetPoint );
double read_CoolerBackoffPoint();
@@ -231,7 +231,7 @@ public:
long InitTwelveBitAD();
long WriteTwelveBitOffset();
- void UpdateGeneraltqStatus();
+ void UpdateGeneralStatus();
// Internal private variables
bool m_ResetVerticalArrays;
@@ -264,13 +264,13 @@ public:
double m_pvtCoolerBackoffPoint;
- Apn_CoolertqStatus m_pvtCoolertqStatus;
- Apn_tqStatus m_pvtImagingtqStatus;
+ Apn_CoolerStatus m_pvtCoolerStatus;
+ Apn_Status m_pvtImagingStatus;
bool m_pvtShutterState;
bool m_pvtImageInProgress;
bool m_pvtImageReady;
- unsigned short m_pvtqStatusReg;
+ unsigned short m_pvtStatusReg;
double m_pvtCoolerDrive;
double m_pvtCurrentHeatsinkTemp;
diff --git a/kstars/kstars/indi/apogee/ApnCamera_Linux.cpp b/kstars/kstars/indi/apogee/ApnCamera_Linux.cpp
index 095dcf0a..cce9ba37 100644
--- a/kstars/kstars/indi/apogee/ApnCamera_Linux.cpp
+++ b/kstars/kstars/indi/apogee/ApnCamera_Linux.cpp
@@ -16,14 +16,14 @@ bool CApnCamera::read_Present()
{
// OutputDebugString( "read_Present()" );
- USHORT AptqStatus;
+ USHORT ApStatus;
USHORT DatumA;
USHORT DatumB;
char szMsg[80];
DatumA = 0x0;
DatumB = 0x0;
- AptqStatus = 0;
+ ApStatus = 0;
Write( FPGA_REG_SCRATCH, 0x8086 );
Read( FPGA_REG_SCRATCH, DatumA );
diff --git a/kstars/kstars/indi/apogee/ApnCamera_NET.cpp b/kstars/kstars/indi/apogee/ApnCamera_NET.cpp
index 9a11d6c4..0f739121 100644
--- a/kstars/kstars/indi/apogee/ApnCamera_NET.cpp
+++ b/kstars/kstars/indi/apogee/ApnCamera_NET.cpp
@@ -92,7 +92,7 @@ bool CApnCamera::GetImageData( unsigned short *pImageBuffer,
while ( !ImageReady() )
{
Sleep( 50 );
- read_ImagingtqStatus();
+ read_ImagingStatus();
}
Width = m_pvtWidth;
@@ -238,7 +238,7 @@ long CApnCamera::WriteMultiMRMD( unsigned short reg[], unsigned short val[], uns
}
-long CApnCamera::QuerytqStatusRegs( unsigned short& tqStatusReg,
+long CApnCamera::QueryStatusRegs( unsigned short& StatusReg,
unsigned short& HeatsinkTempReg,
unsigned short& CcdTempReg,
unsigned short& CoolerDriveReg,
@@ -262,7 +262,7 @@ long CApnCamera::QuerytqStatusRegs( unsigned short& tqStatusReg,
return 1;
}
- tqStatusReg = RegData[0];
+ StatusReg = RegData[0];
HeatsinkTempReg = RegData[1];
CcdTempReg = RegData[2];
CoolerDriveReg = RegData[3];
diff --git a/kstars/kstars/indi/apogee/ApnCamera_NET.h b/kstars/kstars/indi/apogee/ApnCamera_NET.h
index 210e8d29..e46d3846 100644
--- a/kstars/kstars/indi/apogee/ApnCamera_NET.h
+++ b/kstars/kstars/indi/apogee/ApnCamera_NET.h
@@ -61,7 +61,7 @@ public:
unsigned short val[],
unsigned short count );
- long QuerytqStatusRegs( unsigned short& tqStatusReg,
+ long QueryStatusRegs( unsigned short& StatusReg,
unsigned short& HeatsinkTempReg,
unsigned short& CcdTempReg,
unsigned short& CoolerDriveReg,
diff --git a/kstars/kstars/indi/apogee/ApnCamera_USB.cpp b/kstars/kstars/indi/apogee/ApnCamera_USB.cpp
index 090ac3c1..a6bbad42 100644
--- a/kstars/kstars/indi/apogee/ApnCamera_USB.cpp
+++ b/kstars/kstars/indi/apogee/ApnCamera_USB.cpp
@@ -76,7 +76,7 @@ bool CApnCamera::GetImageData( unsigned short *pImageBuffer,
while ( !ImageReady() )
{
Sleep( 50 );
- read_ImagingtqStatus();
+ read_ImagingStatus();
}
Width = m_pvtWidth;
@@ -161,7 +161,7 @@ long CApnCamera::PostStopExposure( bool DigitizeData )
while ( !ImageReady() )
{
Sleep( 50 );
- read_ImagingtqStatus();
+ read_ImagingStatus();
}
pRequestData = new USHORT[m_pvtWidth*m_pvtHeight];
@@ -228,7 +228,7 @@ long CApnCamera::WriteMultiMRMD( unsigned short reg[], unsigned short val[], uns
}
-long CApnCamera::QuerytqStatusRegs( unsigned short& tqStatusReg,
+long CApnCamera::QueryStatusRegs( unsigned short& StatusReg,
unsigned short& HeatsinkTempReg,
unsigned short& CcdTempReg,
unsigned short& CoolerDriveReg,
@@ -238,7 +238,7 @@ long CApnCamera::QuerytqStatusRegs( unsigned short& tqStatusReg,
{
/*unsigned short stat,heat,ccdt,cool,volt,tdic,sequ;*/
- if ( ApnUsbReadtqStatusRegs( &tqStatusReg,
+ if ( ApnUsbReadStatusRegs( &StatusReg,
&HeatsinkTempReg,
&CcdTempReg,
&CoolerDriveReg,
diff --git a/kstars/kstars/indi/apogee/ApnCamera_USB.h b/kstars/kstars/indi/apogee/ApnCamera_USB.h
index c8086c38..0d4a3d07 100644
--- a/kstars/kstars/indi/apogee/ApnCamera_USB.h
+++ b/kstars/kstars/indi/apogee/ApnCamera_USB.h
@@ -56,7 +56,7 @@ public:
unsigned short val[],
unsigned short count );
- long QuerytqStatusRegs( unsigned short& tqStatusReg,
+ long QueryStatusRegs( unsigned short& StatusReg,
unsigned short& HeatsinkTempReg,
unsigned short& CcdTempReg,
unsigned short& CoolerDriveReg,
diff --git a/kstars/kstars/indi/apogee/Apogee.h b/kstars/kstars/indi/apogee/Apogee.h
index cee9b37c..d97740b2 100644
--- a/kstars/kstars/indi/apogee/Apogee.h
+++ b/kstars/kstars/indi/apogee/Apogee.h
@@ -29,15 +29,15 @@
#define Apn_CameraMode_ExternalTrigger 3
#define Apn_CameraMode_ExternalShutter 4
-#define Apn_tqStatus int
-#define Apn_tqStatus_DataError -2
-#define Apn_tqStatus_PatternError -1
-#define Apn_tqStatus_Idle 0
-#define Apn_tqStatus_Exposing 1
-#define Apn_tqStatus_ImagingActive 2
-#define Apn_tqStatus_ImageReady 3
-#define Apn_tqStatus_Flushing 4
-#define Apn_tqStatus_WaitingOnTrigger 5
+#define Apn_Status int
+#define Apn_Status_DataError -2
+#define Apn_Status_PatternError -1
+#define Apn_Status_Idle 0
+#define Apn_Status_Exposing 1
+#define Apn_Status_ImagingActive 2
+#define Apn_Status_ImageReady 3
+#define Apn_Status_Flushing 4
+#define Apn_Status_WaitingOnTrigger 5
#define Apn_LedMode int
#define Apn_LedMode_DisableAll 0
@@ -54,11 +54,11 @@
#define Apn_LedState_ExtStartReadout 6
#define Apn_LedState_AtTemp 7
-#define Apn_CoolertqStatus int
-#define Apn_CoolertqStatus_Off 0
-#define Apn_CoolertqStatus_RampingToSetPoint 1
-#define Apn_CoolertqStatus_AtSetPoint 2
-#define Apn_CoolertqStatus_Revision 3
+#define Apn_CoolerStatus int
+#define Apn_CoolerStatus_Off 0
+#define Apn_CoolerStatus_RampingToSetPoint 1
+#define Apn_CoolerStatus_AtSetPoint 2
+#define Apn_CoolerStatus_Revision 3
#define Apn_FanMode int
#define Apn_FanMode_Off 0
@@ -67,24 +67,24 @@
#define Apn_FanMode_High 3
-#define Camera_tqStatus int
-#define Camera_tqStatus_Idle 0
-#define Camera_tqStatus_Waiting 1
-#define Camera_tqStatus_Exposing 2
-#define Camera_tqStatus_Downloading 3
-#define Camera_tqStatus_LineReady 4
-#define Camera_tqStatus_ImageReady 5
-#define Camera_tqStatus_Flushing 6
-
-#define Camera_CoolertqStatus int
-#define Camera_CoolertqStatus_Off 0
-#define Camera_CoolertqStatus_RampingToSetPoint 1
-#define Camera_CoolertqStatus_Correcting 2
-#define Camera_CoolertqStatus_RampingToAmbient 3
-#define Camera_CoolertqStatus_AtAmbient 4
-#define Camera_CoolertqStatus_AtMax 5
-#define Camera_CoolertqStatus_AtMin 6
-#define Camera_CoolertqStatus_AtSetPoint 7
+#define Camera_Status int
+#define Camera_Status_Idle 0
+#define Camera_Status_Waiting 1
+#define Camera_Status_Exposing 2
+#define Camera_Status_Downloading 3
+#define Camera_Status_LineReady 4
+#define Camera_Status_ImageReady 5
+#define Camera_Status_Flushing 6
+
+#define Camera_CoolerStatus int
+#define Camera_CoolerStatus_Off 0
+#define Camera_CoolerStatus_RampingToSetPoint 1
+#define Camera_CoolerStatus_Correcting 2
+#define Camera_CoolerStatus_RampingToAmbient 3
+#define Camera_CoolerStatus_AtAmbient 4
+#define Camera_CoolerStatus_AtMax 5
+#define Camera_CoolerStatus_AtMin 6
+#define Camera_CoolerStatus_AtSetPoint 7
#define Camera_CoolerMode int
#define Camera_CoolerMode_Off 0
diff --git a/kstars/kstars/indi/apogee/ApogeeIoctl.h b/kstars/kstars/indi/apogee/ApogeeIoctl.h
index 42ac1d8f..ec0fc580 100644
--- a/kstars/kstars/indi/apogee/ApogeeIoctl.h
+++ b/kstars/kstars/indi/apogee/ApogeeIoctl.h
@@ -4,7 +4,7 @@
//
//Portions Copyright (c) 2000 The Random Factory.
//
-// Define the IOCTL codes we will use. The IOCTL code tqcontains a command
+// Define the IOCTL codes we will use. The IOCTL code contains a command
// identifier, plus other information about the device, the type of access
// with which the file must have been opened, and the type of buffering.
//
diff --git a/kstars/kstars/indi/apogee/ApogeeUsb.h b/kstars/kstars/indi/apogee/ApogeeUsb.h
index 6924ffab..f242ea6a 100644
--- a/kstars/kstars/indi/apogee/ApogeeUsb.h
+++ b/kstars/kstars/indi/apogee/ApogeeUsb.h
@@ -61,7 +61,7 @@ APN_USB_TYPE ApnUsbWriteRegMultiMRMD( unsigned short FpgaReg[],
unsigned short RegCount );
-APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
+APN_USB_TYPE ApnUsbReadStatusRegs( unsigned short *StatusReg,
unsigned short *HeatsinkTempReg,
unsigned short *CcdTempReg,
unsigned short *CoolerDriveReg,
diff --git a/kstars/kstars/indi/apogee/ApogeeUsbLinux.cpp b/kstars/kstars/indi/apogee/ApogeeUsbLinux.cpp
index 2d51d147..fcedd1d9 100644
--- a/kstars/kstars/indi/apogee/ApogeeUsbLinux.cpp
+++ b/kstars/kstars/indi/apogee/ApogeeUsbLinux.cpp
@@ -192,7 +192,7 @@ APN_USB_TYPE ApnUsbWriteRegMultiMRMD( unsigned short FpgaReg[],
}
-APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
+APN_USB_TYPE ApnUsbReadStatusRegs( unsigned short *StatusReg,
unsigned short *HeatsinkTempReg,
unsigned short *CcdTempReg,
unsigned short *CoolerDriveReg,
@@ -203,15 +203,15 @@ APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
BOOLEAN Success;
/*unsigned int BytesReceived;*/
unsigned short *Data;
- unsigned char tqStatusData[21];
+ unsigned char StatusData[21];
Success = usb_control_msg(g_hSysDriver,
USB_DIR_IN | USB_TYPE_VENDOR | USB_RECIP_DEVICE, VND_APOGEE_STATUS,
- 0, 0, (char *)&tqStatusData, 21, 3000);
+ 0, 0, (char *)&StatusData, 21, 3000);
// if ( !Success )
// return APN_USB_ERR_STATUS;
- Data = (unsigned short *)tqStatusData;
+ Data = (unsigned short *)StatusData;
*HeatsinkTempReg = Data[0];
*CcdTempReg = Data[1];
@@ -219,11 +219,11 @@ APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
*VoltageReg = Data[3];
*TdiCounter = Data[4];
*SequenceCounter = Data[5];
- *tqStatusReg = Data[6];
+ *StatusReg = Data[6];
- if ( (tqStatusData[20] & 0x01) != 0 )
+ if ( (StatusData[20] & 0x01) != 0 )
{
- *tqStatusReg |= 0x8;
+ *StatusReg |= 0x8;
}
return APN_USB_SUCCESS;
diff --git a/kstars/kstars/indi/apogee/ApogeeUsbLinuxForKernel.cpp b/kstars/kstars/indi/apogee/ApogeeUsbLinuxForKernel.cpp
index cae78e59..4cbb77b2 100644
--- a/kstars/kstars/indi/apogee/ApogeeUsbLinuxForKernel.cpp
+++ b/kstars/kstars/indi/apogee/ApogeeUsbLinuxForKernel.cpp
@@ -213,7 +213,7 @@ APN_USB_TYPE ApnUsbWriteRegMultiMRMD( unsigned short FpgaReg[],
}
-APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
+APN_USB_TYPE ApnUsbReadStatusRegs( unsigned short *StatusReg,
unsigned short *HeatsinkTempReg,
unsigned short *CcdTempReg,
unsigned short *CoolerDriveReg,
@@ -226,15 +226,15 @@ APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
unsigned short RegNumber;
struct apIOparam request;
unsigned short *Data;
- unsigned char tqStatusData[21];
+ unsigned char StatusData[21];
request.reg = 0; //check this *******************
- request.param1=(unsigned long)&tqStatusData;
+ request.param1=(unsigned long)&StatusData;
Success=ioctl(g_hSysDriver,APUSB_READ_STATUS,(unsigned long)&request);
// if ( !Success )
// return APN_USB_ERR_STATUS;
- Data = (unsigned short *)tqStatusData;
+ Data = (unsigned short *)StatusData;
*HeatsinkTempReg = Data[0];
*CcdTempReg = Data[1];
@@ -242,11 +242,11 @@ APN_USB_TYPE ApnUsbReadtqStatusRegs( unsigned short *tqStatusReg,
*VoltageReg = Data[3];
*TdiCounter = Data[4];
*SequenceCounter = Data[5];
- *tqStatusReg = Data[6];
+ *StatusReg = Data[6];
- if ( (tqStatusData[20] & 0x01) != 0 )
+ if ( (StatusData[20] & 0x01) != 0 )
{
- *tqStatusReg |= 0x8;
+ *StatusReg |= 0x8;
}
return APN_USB_SUCCESS;
diff --git a/kstars/kstars/indi/apogee/CameraIO_Linux.h b/kstars/kstars/indi/apogee/CameraIO_Linux.h
index 6edfe467..d6a61e1c 100644
--- a/kstars/kstars/indi/apogee/CameraIO_Linux.h
+++ b/kstars/kstars/indi/apogee/CameraIO_Linux.h
@@ -104,8 +104,8 @@ const long Reg_TempData = 9; // Register 10
const unsigned short RegBitShift_TempData = 0; // Bit 0
const unsigned short RegBitMask_TempData = 0xFF; // 8 bits
-const long RegISA_tqStatus = 0x006; // Register 11 in firmware
-const long Reg_tqStatus = 10; // Register 11
+const long RegISA_Status = 0x006; // Register 11 in firmware
+const long Reg_Status = 10; // Register 11
const unsigned short RegBit_Exposing = 0x1; // Bit 0
const unsigned short RegBit_LineDone = 0x2; // Bit 1
const unsigned short RegBit_CacheReadOK = 0x4; // Bit 2
@@ -139,7 +139,7 @@ const long RegPCI_BICCounter = 0x01C; // Register 8 in PCI fir
const long RegPCI_BICCounterRead = 0x03C;
const long RegPCI_ImageData = 0x000; // Register 9 in PCI firmware
const long RegPCI_TempData = 0x004; // Register 10 in PCI firmware
-const long RegPCI_tqStatus = 0x00C; // Register 11 in firmware
+const long RegPCI_Status = 0x00C; // Register 11 in firmware
const long RegPCI_CommandReadback = 0x010; // Register 12 in PCI firmware
@@ -161,7 +161,7 @@ public:
////////////////////////////////////////////////////////////
// Camera Settings
- Camera_tqStatus read_tqStatus(); // Current camera state
+ Camera_Status read_Status(); // Current camera state
// <0: error codes
// 0: idle
// 1: flushing
@@ -223,7 +223,7 @@ public:
double read_CoolerSetPoint(); // Returns/sets setpoint temperature in degrees
void write_CoolerSetPoint( double val ); // Celcius.
- Camera_CoolertqStatus read_CoolertqStatus(); // Returns current cooler status
+ Camera_CoolerStatus read_CoolerStatus(); // Returns current cooler status
Camera_CoolerMode read_CoolerMode(); // Returns/sets current cooler operation mode.
void write_CoolerMode( Camera_CoolerMode val );
@@ -271,8 +271,8 @@ public:
// Mask user requested set of IRQS
// void MaskIrqs();
- // Restore default IRQ tqmask
-// void UntqmaskIrqs();
+ // Restore default IRQ mask
+// void UnmaskIrqs();
// Starts flushing the camera (which should be the normal idle state)
// If Rows is non-negative, only the specified number of rows are flushed,
@@ -300,7 +300,7 @@ public:
// The Duration parameter is the exposure time in seconds. The Light parameter controls
// the status of the shutter during the exposure, Light = True opens the shutter, Light
- // = False closes the shutter. Returns immediately after invocation, poll the CameratqStatus
+ // = False closes the shutter. Returns immediately after invocation, poll the CameraStatus
// property to determine the start time of a triggered exposure and the end of an exposure.
bool Expose( double Duration, bool Light );
@@ -314,7 +314,7 @@ public:
// Drift scan methods
// Begins clocking and digitization of a single line of data begining with a vertical clock
- // sequence and ending with a buffer full of line data. Poll the CameratqStatus property to
+ // sequence and ending with a buffer full of line data. Poll the CameraStatus property to
// determine when the data is ready for download.
bool DigitizeLine();
@@ -346,7 +346,7 @@ public:
short m_FilterStepPos; // Current filter position in our internal array
bool m_Shutter; // Last known shutter state
- Camera_tqStatus m_tqStatus; // Last known camera status
+ Camera_Status m_Status; // Last known camera status
Camera_Interface m_Interface; // String acronyms may be used in INI file.
// 0 or ISA: Industry Standard Architecture bus
@@ -356,8 +356,8 @@ public:
Camera_SensorType m_SensorType; // 0 or CCD: Charge Coupled Device
// 1 or CMOS: Complementary Metal-Oxide-Silicon
- Camera_CoolertqStatus m_CoolertqStatus; // Last known cooler status.
- unsigned int m_IRQMask; // Set of IRQs tqmasked on user request // 0: Off
+ Camera_CoolerStatus m_CoolerStatus; // Last known cooler status.
+ unsigned int m_IRQMask; // Set of IRQs masked on user request // 0: Off
// 1: Ramping to set point
// 2: Correcting
// 3: Ramping to ambient
diff --git a/kstars/kstars/indi/apogee/CameraIO_LinuxISA.cpp b/kstars/kstars/indi/apogee/CameraIO_LinuxISA.cpp
index bbff2080..16a6bb72 100644
--- a/kstars/kstars/indi/apogee/CameraIO_LinuxISA.cpp
+++ b/kstars/kstars/indi/apogee/CameraIO_LinuxISA.cpp
@@ -145,8 +145,8 @@ long CCameraIO::Read( unsigned short reg, unsigned short& val )
case Reg_TempData:
realreg = RegISA_TempData;
break;
- case Reg_tqStatus:
- realreg = RegISA_tqStatus;
+ case Reg_Status:
+ realreg = RegISA_Status;
break;
case Reg_CommandReadback:
realreg = RegISA_CommandReadback;
@@ -212,7 +212,7 @@ long CCameraIO::ReadLine( long SkipPixels, long Pixels,unsigned short* pLineBuff
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
if ( clock() > StopTime ) return 1; // Timed out
@@ -301,7 +301,7 @@ long CCameraIO::InternalReadLine( bool KeepData, long SkipC, long XEnd, unsigned
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
clock_t CurrentTime = clock();
diff --git a/kstars/kstars/indi/apogee/CameraIO_LinuxPCI.cpp b/kstars/kstars/indi/apogee/CameraIO_LinuxPCI.cpp
index 15c139dd..a83a594e 100644
--- a/kstars/kstars/indi/apogee/CameraIO_LinuxPCI.cpp
+++ b/kstars/kstars/indi/apogee/CameraIO_LinuxPCI.cpp
@@ -199,8 +199,8 @@ long CCameraIO::Read( unsigned short reg, unsigned short& val )
case Reg_TempData:
RegNumber = RegPCI_TempData;
break;
- case Reg_tqStatus:
- RegNumber = RegPCI_tqStatus;
+ case Reg_Status:
+ RegNumber = RegPCI_Status;
break;
case Reg_CommandReadback:
RegNumber = RegPCI_CommandReadback;
@@ -266,7 +266,7 @@ long CCameraIO::ReadLine( long SkipPixels, long Pixels,unsigned short* pLineBuff
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
if ( clock() > StopTime ) return 1; // Timed out
@@ -355,7 +355,7 @@ long CCameraIO::InternalReadLine( bool KeepData, long SkipC, long XEnd, unsigned
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
clock_t CurrentTime = clock();
diff --git a/kstars/kstars/indi/apogee/CameraIO_LinuxPPI.cpp b/kstars/kstars/indi/apogee/CameraIO_LinuxPPI.cpp
index bb143e55..7025d9ce 100644
--- a/kstars/kstars/indi/apogee/CameraIO_LinuxPPI.cpp
+++ b/kstars/kstars/indi/apogee/CameraIO_LinuxPPI.cpp
@@ -147,8 +147,8 @@ long CCameraIO::Read( unsigned short reg, unsigned short& val )
case Reg_TempData:
realreg = RegISA_TempData;
break;
- case Reg_tqStatus:
- realreg = RegISA_tqStatus;
+ case Reg_Status:
+ realreg = RegISA_Status;
break;
case Reg_CommandReadback:
realreg = RegISA_CommandReadback;
@@ -216,7 +216,7 @@ long CCameraIO::ReadLine( long SkipPixels, long Pixels,unsigned short* pLineBuff
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
if ( clock() > StopTime ) return 1; // Timed out
@@ -307,7 +307,7 @@ long CCameraIO::InternalReadLine( bool KeepData, long SkipC, long XEnd, unsigned
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
clock_t CurrentTime = clock();
diff --git a/kstars/kstars/indi/apogee/CameraIO_PCI.cpp b/kstars/kstars/indi/apogee/CameraIO_PCI.cpp
index ba9ce96d..3e6cc43e 100644
--- a/kstars/kstars/indi/apogee/CameraIO_PCI.cpp
+++ b/kstars/kstars/indi/apogee/CameraIO_PCI.cpp
@@ -65,8 +65,8 @@ long CCameraIO_PCI::Read(unsigned short reg, unsigned short& val)
case Reg_TempData:
RegNumber = RegPCI_TempData;
break;
- case Reg_tqStatus:
- RegNumber = RegPCI_tqStatus;
+ case Reg_Status:
+ RegNumber = RegPCI_Status;
break;
case Reg_CommandReadback:
RegNumber = RegPCI_CommandReadback;
@@ -268,7 +268,7 @@ long CCameraIO_PCI::ReadLine( long SkipPixels, long Pixels, unsigned short* pLin
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break;// Line done
if ( clock() > StopTime ) return 1; // Timed out
diff --git a/kstars/kstars/indi/apogee_ppi.cpp b/kstars/kstars/indi/apogee_ppi.cpp
index 26efb4cc..9898018f 100644
--- a/kstars/kstars/indi/apogee_ppi.cpp
+++ b/kstars/kstars/indi/apogee_ppi.cpp
@@ -393,7 +393,7 @@ void ApogeeCam::ISNewNumber (const char */*dev*/, const char *name, double value
void ApogeeCam::ISPoll()
{
static int mtc=5;
- int readtqStatus=0;
+ int readStatus=0;
double ccdTemp;
if (!isCCDConnected())
@@ -407,16 +407,16 @@ void ApogeeCam::ISPoll()
case IPS_BUSY:
- readtqStatus = cam->read_tqStatus();
- if (readtqStatus < 0)
+ readStatus = cam->read_Status();
+ if (readStatus < 0)
{
- IDLog("Error in exposure! Read status: %d\n", readtqStatus);
+ IDLog("Error in exposure! Read status: %d\n", readStatus);
ExposeTimeNP.s = IPS_ALERT;
ExposeTimeN[0].value = 0;
- IDSetNumber(&ExposeTimeNP, "Error in exposure procedure. Read states: %d", readtqStatus);
+ IDSetNumber(&ExposeTimeNP, "Error in exposure procedure. Read states: %d", readStatus);
return;
}
- else if (readtqStatus == Camera_tqStatus_ImageReady)
+ else if (readStatus == Camera_Status_ImageReady)
{
ExposeTimeN[0].value = 0;
ExposeTimeNP.s = IPS_OK;
@@ -891,7 +891,7 @@ bool ApogeeCam::initCamera()
{
LilXML *XMLParser = newLilXML();
XMLEle *root = NULL, *camera = NULL, *ele = NULL;
- XMLEle *system = NULL, *tqgeometry = NULL, *temp = NULL, *ccd = NULL;
+ XMLEle *system = NULL, *geometry = NULL, *temp = NULL, *ccd = NULL;
XMLAtt *ap;
FILE *spFile = NULL;
char errmsg[1024];
@@ -948,7 +948,7 @@ bool ApogeeCam::initCamera()
// Let's get the subsections now
system = findXMLEle(camera, "System");
- tqgeometry = findXMLEle(camera, "Geometry");
+ geometry = findXMLEle(camera, "Geometry");
temp = findXMLEle(camera, "Temp");
ccd = findXMLEle(camera, "CCD");
@@ -960,7 +960,7 @@ bool ApogeeCam::initCamera()
return false;
}
- if (tqgeometry == NULL)
+ if (geometry == NULL)
{
IDLog("Error: Unable to find Geometry element in camera.\n");
IDMessage(mydev, "Error: Unable to find Geometry element in camera.");
@@ -1000,7 +1000,7 @@ bool ApogeeCam::initCamera()
bAddr = hextoi(valuXMLAtt(findXMLAtt(system, "Base"))) & 0xFFF;
// Rows
- ap = findXMLAtt(tqgeometry, "Rows");
+ ap = findXMLAtt(geometry, "Rows");
if (!ap)
{
IDLog("Error: Unable to find attribute Rows.\n");
@@ -1012,7 +1012,7 @@ bool ApogeeCam::initCamera()
cam->m_Rows = hextoi(valuXMLAtt(ap));
// Columns
- ap = findXMLAtt(tqgeometry, "Columns");
+ ap = findXMLAtt(geometry, "Columns");
if (!ap)
{
IDLog("Error: Unable to find attribute Columns.\n");
@@ -1210,7 +1210,7 @@ bool ApogeeCam::initCamera()
}
// BIC
- ele = findXMLEle(tqgeometry, "BIC");
+ ele = findXMLEle(geometry, "BIC");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1219,7 +1219,7 @@ bool ApogeeCam::initCamera()
}
// BIR
- ele = findXMLEle(tqgeometry, "BIR");
+ ele = findXMLEle(geometry, "BIR");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1228,7 +1228,7 @@ bool ApogeeCam::initCamera()
}
// SKIPC
- ele = findXMLEle(tqgeometry, "SKIPC");
+ ele = findXMLEle(geometry, "SKIPC");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1237,7 +1237,7 @@ bool ApogeeCam::initCamera()
}
// SKIPR
- ele = findXMLEle(tqgeometry, "SKIPR");
+ ele = findXMLEle(geometry, "SKIPR");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1246,7 +1246,7 @@ bool ApogeeCam::initCamera()
}
// IMG COlS
- ele = findXMLEle(tqgeometry, "ImgCols");
+ ele = findXMLEle(geometry, "ImgCols");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1257,7 +1257,7 @@ bool ApogeeCam::initCamera()
cam->m_ImgColumns = cam->m_Columns - cam->m_BIC - cam->m_SkipC;
// IMG ROWS
- ele = findXMLEle(tqgeometry, "ImgRows");
+ ele = findXMLEle(geometry, "ImgRows");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1268,7 +1268,7 @@ bool ApogeeCam::initCamera()
cam->m_ImgRows = cam->m_Rows - cam->m_BIR - cam->m_SkipR;
// Hor Flush
- ele = findXMLEle(tqgeometry, "HFlush");
+ ele = findXMLEle(geometry, "HFlush");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
@@ -1277,7 +1277,7 @@ bool ApogeeCam::initCamera()
}
// Ver Flush
- ele = findXMLEle(tqgeometry, "VFlush");
+ ele = findXMLEle(geometry, "VFlush");
if (ele)
{
val = hextoi(pcdataXMLEle(ele));
diff --git a/kstars/kstars/indi/celestronprotocol.h b/kstars/kstars/indi/celestronprotocol.h
index aae4f204..d7c956f7 100644
--- a/kstars/kstars/indi/celestronprotocol.h
+++ b/kstars/kstars/indi/celestronprotocol.h
@@ -2,7 +2,7 @@
* Header File for the Telescope Control protocols for the Meade LX200
* Author: John Kielkopf (kielkopf@louisville.edu)
*
-* This file tqcontains header information used in common with xmtel.
+* This file contains header information used in common with xmtel.
*
* 15 May 2003 -- Version 2.00
*
diff --git a/kstars/kstars/indi/fitsrw.c b/kstars/kstars/indi/fitsrw.c
index ac2c0e39..b21622bf 100644
--- a/kstars/kstars/indi/fitsrw.c
+++ b/kstars/kstars/indi/fitsrw.c
@@ -1676,7 +1676,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{double offs, scale;
double datadiff, pixdiff;
unsigned char pixbuffer[4096], *pix, *cdata;
- unsigned char ctqreplace;
+ unsigned char creplace;
int transcount = 0;
long tdata, tmin, tmax;
int maxelem;
@@ -1706,7 +1706,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
if (tmax < 0) tmax = 0; else if (tmax > 255) tmax = 255;
cdata = (unsigned char *)buf;
- ctqreplace = (unsigned char)trans->tqreplacement;
+ creplace = (unsigned char)trans->replacement;
switch (hdulist->bitpix)
{
@@ -1727,7 +1727,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
bp8 = (FITS_BITPIX8)*(pix++);
if (bp8 == bp8blank) /* Is it a blank pixel ? */
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else /* Do transform */
{
tdata = (long)(bp8 * scale + offs);
@@ -1770,7 +1770,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
FITS_GETBITPIX16 (pix, bp16);
if (bp16 == bp16blank)
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
tdata = (long)(bp16 * scale + offs);
@@ -1815,7 +1815,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
FITS_GETBITPIX32 (pix, bp32);
if (bp32 == bp32blank)
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
tdata = (long)(bp32 * scale + offs);
@@ -1856,7 +1856,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
while (maxelem--)
{
if (fits_nan_32 (pix)) /* An IEEE special value ? */
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else /* Do transform */
{
FITS_GETBITPIXM32 (pix, bpm32);
@@ -1884,7 +1884,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
while (maxelem--)
{
if (fits_nan_64 (pix))
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
FITS_GETBITPIXM64 (pix, bpm64);
@@ -1953,7 +1953,7 @@ int fits_to_pgmraw (char *fitsfile, char *pgmfile)
trans.pixmax = hdu->pixmax;
trans.datamin = 0.0;
trans.datamax = 255.0;
- trans.tqreplacement = 0.0; /* Blank/NaN tqreplacement value */
+ trans.replacement = 0.0; /* Blank/NaN replacement value */
trans.dsttyp = 'c'; /* Output type is character */
nbytes = hdu->naxisn[0]*hdu->naxisn[1];
diff --git a/kstars/kstars/indi/fitsrw.h b/kstars/kstars/indi/fitsrw.h
index 37a80492..9a246930 100644
--- a/kstars/kstars/indi/fitsrw.h
+++ b/kstars/kstars/indi/fitsrw.h
@@ -82,7 +82,7 @@ typedef enum {
typedef struct {
double pixmin, pixmax; /** The pixel values [pixmin,pixmax] that should be mapped */
double datamin, datamax; /** The data values [datamin,datamax] that the pixel values should be mapped to*/
- double tqreplacement; /** datavalue to use for blank or NaN pixels */
+ double replacement; /** datavalue to use for blank or NaN pixels */
char dsttyp; /** Destination typ ('c' = char) */
} FITS_PIX_TRANSFORM;
@@ -110,7 +110,7 @@ typedef struct fits_record_list {
/** \struct FITS_HDU_LIST
\brief Header and Data Unit List.
-* The structure hold header and data unit lists. The \p used struct tqcontains flags specifying if some cards are used.
+* The structure hold header and data unit lists. The \p used struct contains flags specifying if some cards are used.
*/
typedef struct fits_hdu_list {
long header_offset; /** Offset of header in the file */
diff --git a/kstars/kstars/indi/fli/libfli.c b/kstars/kstars/indi/fli/libfli.c
index d3962a62..68df7945 100644
--- a/kstars/kstars/indi/fli/libfli.c
+++ b/kstars/kstars/indi/fli/libfli.c
@@ -489,7 +489,7 @@ LIBFLIAPI FLIGetVisibleArea(flidev_t dev, long* ul_x, long* ul_y,
@see FLIExposeFrame
@see FLICancelExposure
- @see FLIGetExposuretqStatus
+ @see FLIGetExposureStatus
*/
LIBFLIAPI FLISetExposureTime(flidev_t dev, long exptime)
{
@@ -626,7 +626,7 @@ LIBFLIAPI FLISetFrameType(flidev_t dev, fliframe_t frametype)
@return Non-zero on failure.
@see FLIExposeFrame
- @see FLIGetExposuretqStatus
+ @see FLIGetExposureStatus
@see FLISetExposureTime
*/
LIBFLIAPI FLICancelExposure(flidev_t dev)
@@ -652,7 +652,7 @@ LIBFLIAPI FLICancelExposure(flidev_t dev)
@see FLICancelExposure
@see FLISetExposureTime
*/
-LIBFLIAPI FLIGetExposuretqStatus(flidev_t dev, long *timeleft)
+LIBFLIAPI FLIGetExposureStatus(flidev_t dev, long *timeleft)
{
CHKDEVICE(dev);
@@ -752,7 +752,7 @@ LIBFLIAPI FLIGrabRow(flidev_t dev, void *buff, size_t width)
@see FLISetBitDepth
@see FLIGrabFrame
@see FLICancelExposure
- @see FLIGetExposuretqStatus
+ @see FLIGetExposureStatus
*/
LIBFLIAPI FLIExposeFrame(flidev_t dev)
{
diff --git a/kstars/kstars/indi/fli/libfli.h b/kstars/kstars/indi/fli/libfli.h
index ca6a7200..351a9e8e 100644
--- a/kstars/kstars/indi/fli/libfli.h
+++ b/kstars/kstars/indi/fli/libfli.h
@@ -176,7 +176,7 @@ LIBFLIAPI FLISetHBin(flidev_t dev, long hbin);
LIBFLIAPI FLISetVBin(flidev_t dev, long vbin);
LIBFLIAPI FLISetFrameType(flidev_t dev, fliframe_t frametype);
LIBFLIAPI FLICancelExposure(flidev_t dev);
-LIBFLIAPI FLIGetExposuretqStatus(flidev_t dev, long *timeleft);
+LIBFLIAPI FLIGetExposureStatus(flidev_t dev, long *timeleft);
LIBFLIAPI FLISetTemperature(flidev_t dev, double temperature);
LIBFLIAPI FLIGetTemperature(flidev_t dev, double *temperature);
LIBFLIAPI FLIGrabRow(flidev_t dev, void *buff, size_t width);
diff --git a/kstars/kstars/indi/fli_ccd.c b/kstars/kstars/indi/fli_ccd.c
index 2ce10786..4fa9a95a 100644
--- a/kstars/kstars/indi/fli_ccd.c
+++ b/kstars/kstars/indi/fli_ccd.c
@@ -610,13 +610,13 @@ void ISPoll(void *p)
break;
case IPS_BUSY:
- if ( (err = FLIGetExposuretqStatus(fli_dev, &timeleft)))
+ if ( (err = FLIGetExposureStatus(fli_dev, &timeleft)))
{
ExposeTimeNP.s = IPS_IDLE;
ExposeTimeN[0].value = 0;
- IDSetNumber(&ExposeTimeNP, "FLIGetExposuretqStatus() failed. %s.", strerror((int)-err));
- IDLog("FLIGetExposuretqStatus() failed. %s.\n", strerror((int)-err));
+ IDSetNumber(&ExposeTimeNP, "FLIGetExposureStatus() failed. %s.", strerror((int)-err));
+ IDLog("FLIGetExposureStatus() failed. %s.\n", strerror((int)-err));
break;
}
diff --git a/kstars/kstars/indi/indiserver.c b/kstars/kstars/indi/indiserver.c
index c412e883..ad4d2ffd 100644
--- a/kstars/kstars/indi/indiserver.c
+++ b/kstars/kstars/indi/indiserver.c
@@ -710,7 +710,7 @@ send2Clients (ClInfo *notme, XMLEle *root, char *dev)
pthread_mutex_unlock (&client_m);
}
-/* free Msg mp and everything it tqcontains */
+/* free Msg mp and everything it contains */
static void
freeMsg (Msg *mp)
{
diff --git a/kstars/kstars/indi/lilxml.c b/kstars/kstars/indi/lilxml.c
index be9d6bac..c8344b5e 100644
--- a/kstars/kstars/indi/lilxml.c
+++ b/kstars/kstars/indi/lilxml.c
@@ -532,7 +532,7 @@ oneXMLchar (LilXML *lp, int c, char errmsg[])
case INCON: /* reading content */
if (c == '<') {
- /* if text tqcontains a nl trim trailing blanks.
+ /* if text contains a nl trim trailing blanks.
* chomp trailing nl if only one.
*/
char *nl = strpbrk (lp->ce->pcdata, "\n\r");
diff --git a/kstars/kstars/indi/lx200_16.cpp b/kstars/kstars/indi/lx200_16.cpp
index 8b705728..fe37df18 100644
--- a/kstars/kstars/indi/lx200_16.cpp
+++ b/kstars/kstars/indi/lx200_16.cpp
@@ -54,7 +54,7 @@ extern int MaxReticleFlashRate;
// bool setObjAz(int degrees, int minutes);
-static ISwitch FantqStatusS[] = { {"On", "", ISS_OFF, 0, 0}, {"Off", "", ISS_OFF, 0, 0}};
+static ISwitch FanStatusS[] = { {"On", "", ISS_OFF, 0, 0}, {"Off", "", ISS_OFF, 0, 0}};
static ISwitch HomeSearchS[] = { {"Save home", "", ISS_OFF, 0, 0} , {"Set home", "", ISS_OFF, 0, 0}};
static ISwitch FieldDeRotatorS[] = { {"On", "", ISS_OFF, 0, 0}, {"Off", "", ISS_OFF,0 ,0}};
//static ISwitch SlewAltAzS[] = { {"Slew To Alt/Az", ISS_ON}};
@@ -65,7 +65,7 @@ static ISwitch FieldDeRotatorS[] = { {"On", "", ISS_OFF, 0, 0}, {"Off", "", ISS_
#define MAXINDIGROUP 32
#define MAXINDIFORMAT 32
-static ISwitchVectorProperty FantqStatusSw = { mydev, "Fan", "", LX16GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FantqStatusS, NARRAY(FantqStatusS), "", 0};
+static ISwitchVectorProperty FanStatusSw = { mydev, "Fan", "", LX16GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FanStatusS, NARRAY(FanStatusS), "", 0};
static ISwitchVectorProperty HomeSearchSw = { mydev, "Park", "", LX16GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, HomeSearchS, NARRAY(HomeSearchS), "", 0};
@@ -85,7 +85,7 @@ static INumberVectorProperty horNum = {
void changeLX200_16DeviceName(const char * newName)
{
strcpy(horNum.device, newName);
- strcpy(FantqStatusSw.device, newName);
+ strcpy(FanStatusSw.device, newName);
strcpy(HomeSearchSw.device, newName);
strcpy(FieldDeRotatorSw.device,newName);
}
@@ -106,7 +106,7 @@ if (dev && strcmp (thisDevice, dev))
IDDefNumber (&horNum, NULL);
- IDDefSwitch (&FantqStatusSw, NULL);
+ IDDefSwitch (&FanStatusSw, NULL);
IDDefSwitch (&HomeSearchSw, NULL);
IDDefSwitch (&FieldDeRotatorSw, NULL);
@@ -196,20 +196,20 @@ void LX200_16::ISNewSwitch (const char *dev, const char *name, ISState *states,
if (strcmp (dev, thisDevice))
return;
- if (!strcmp(name, FantqStatusSw.name))
+ if (!strcmp(name, FanStatusSw.name))
{
- if (checkPower(&FantqStatusSw))
+ if (checkPower(&FanStatusSw))
return;
- IUResetSwitches(&FantqStatusSw);
- IUUpdateSwitches(&FantqStatusSw, states, names, n);
- index = getOnSwitch(&FantqStatusSw);
+ IUResetSwitches(&FanStatusSw);
+ IUUpdateSwitches(&FanStatusSw, states, names, n);
+ index = getOnSwitch(&FanStatusSw);
if (index == 0)
{
if ( (err = turnFanOn()) < 0)
{
- handleError(&FantqStatusSw, err, "Changing fan status");
+ handleError(&FanStatusSw, err, "Changing fan status");
return;
}
}
@@ -217,13 +217,13 @@ void LX200_16::ISNewSwitch (const char *dev, const char *name, ISState *states,
{
if ( (err = turnFanOff()) < 0)
{
- handleError(&FantqStatusSw, err, "Changing fan status");
+ handleError(&FanStatusSw, err, "Changing fan status");
return;
}
}
- FantqStatusSw.s = IPS_OK;
- IDSetSwitch (&FantqStatusSw, index == 0 ? "Fan is ON" : "Fan is OFF");
+ FanStatusSw.s = IPS_OK;
+ IDSetSwitch (&FanStatusSw, index == 0 ? "Fan is ON" : "Fan is OFF");
return;
}
@@ -304,7 +304,7 @@ void LX200_16::handleAltAzSlew()
case IPS_BUSY:
- if ( (err = getHomeSearchtqStatus(&searchResult)) < 0)
+ if ( (err = getHomeSearchStatus(&searchResult)) < 0)
{
handleError(&HomeSearchSw, err, "Home search");
return;
diff --git a/kstars/kstars/indi/lx200driver.c b/kstars/kstars/indi/lx200driver.c
index bd85ba88..9c521cfe 100644
--- a/kstars/kstars/indi/lx200driver.c
+++ b/kstars/kstars/indi/lx200driver.c
@@ -78,8 +78,8 @@ int getCalenderDate(char *date);
int getSiteName(char *siteName, int siteNum);
/* Get Number of Bars */
int getNumberOfBars(int *value);
-/* Get Home Search tqStatus */
-int getHomeSearchtqStatus(int *status);
+/* Get Home Search Status */
+int getHomeSearchStatus(int *status);
/* Get OTA Temperature */
int getOTATemp(double * value);
/* Get time format: 12 or 24 */
@@ -99,7 +99,7 @@ int setStandardProcedure(char * writeData);
/* Set Slew Mode */
int setSlewMode(int slewMode);
/* Set Alignment mode */
-int tqsetAlignmentMode(unsigned int alignMode);
+int setAlignmentMode(unsigned int alignMode);
/* Set Object RA */
int setObjectRA(double ra);
/* set Object DEC */
@@ -203,7 +203,7 @@ int testTelescope()
int testAP()
{
int i=0;
- char tqcurrentDate[64];
+ char currentDate[64];
fprintf(stderr, "Testing telescope's connection...\n");
@@ -211,7 +211,7 @@ int testAP()
/ We're going to request the calander date */
for (i=0; i < 2; i++)
{
- if (!getCalenderDate(tqcurrentDate))
+ if (!getCalenderDate(currentDate))
return 0;
usleep(50000);
@@ -534,7 +534,7 @@ int getNumberOfBars(int *value)
return 0;
}
-int getHomeSearchtqStatus(int *status)
+int getHomeSearchStatus(int *status)
{
char tempString[16];
@@ -726,9 +726,9 @@ int setCommandXYZ(int x, int y, int z, const char *cmd)
return (setStandardProcedure(tempString));
}
-int tqsetAlignmentMode(unsigned int alignMode)
+int setAlignmentMode(unsigned int alignMode)
{
- fprintf(stderr , "Set tqalignment mode %d\n", alignMode);
+ fprintf(stderr , "Set alignment mode %d\n", alignMode);
switch (alignMode)
{
diff --git a/kstars/kstars/indi/lx200driver.h b/kstars/kstars/indi/lx200driver.h
index 529dfa02..06b8017f 100644
--- a/kstars/kstars/indi/lx200driver.h
+++ b/kstars/kstars/indi/lx200driver.h
@@ -157,8 +157,8 @@ int getCalenderDate(char *date);
int getSiteName(char *siteName, int siteNum);
/* Get Number of Bars */
int getNumberOfBars(int *value);
-/* Get Home Search tqStatus */
-int getHomeSearchtqStatus(int *status);
+/* Get Home Search Status */
+int getHomeSearchStatus(int *status);
/* Get OTA Temperature */
int getOTATemp(double * value);
/* Get time format: 12 or 24 */
@@ -178,7 +178,7 @@ int setStandardProcedure(char * writeData);
/* Set Slew Mode */
int setSlewMode(int slewMode);
/* Set Alignment mode */
-int tqsetAlignmentMode(unsigned int alignMode);
+int setAlignmentMode(unsigned int alignMode);
/* Set Object RA */
int setObjectRA(double ra);
/* set Object DEC */
diff --git a/kstars/kstars/indi/lx200generic.cpp b/kstars/kstars/indi/lx200generic.cpp
index 311e4b68..b4f6d792 100644
--- a/kstars/kstars/indi/lx200generic.cpp
+++ b/kstars/kstars/indi/lx200generic.cpp
@@ -906,9 +906,9 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
IUUpdateSwitches(&AlignmentSw, states, names, n);
index = getOnSwitch(&AlignmentSw);
- if ( ( err = tqsetAlignmentMode(index) < 0) )
+ if ( ( err = setAlignmentMode(index) < 0) )
{
- handleError(&AlignmentSw, err, "Setting tqalignment");
+ handleError(&AlignmentSw, err, "Setting alignment");
return;
}
@@ -1789,7 +1789,7 @@ void LX200Generic::getAlignment()
signed char align = ACK();
if (align < 0)
{
- IDSetSwitch (&AlignmentSw, "Failed to get telescope tqalignment.");
+ IDSetSwitch (&AlignmentSw, "Failed to get telescope alignment.");
return;
}
diff --git a/kstars/kstars/indi/lx200gps.cpp b/kstars/kstars/indi/lx200gps.cpp
index 0a02b32e..451a7269 100644
--- a/kstars/kstars/indi/lx200gps.cpp
+++ b/kstars/kstars/indi/lx200gps.cpp
@@ -32,7 +32,7 @@ extern LX200Generic *telescope;
extern int MaxReticleFlashRate;
static ISwitch GPSPowerS[] = {{ "On", "", ISS_OFF, 0, 0}, {"Off", "", ISS_ON, 0, 0}};
-static ISwitch GPStqStatusS[] = {{ "Sleep", "", ISS_OFF, 0, 0}, {"Wake up", "", ISS_OFF, 0 ,0}, {"Restart", "", ISS_OFF, 0, 0}};
+static ISwitch GPSStatusS[] = {{ "Sleep", "", ISS_OFF, 0, 0}, {"Wake up", "", ISS_OFF, 0 ,0}, {"Restart", "", ISS_OFF, 0, 0}};
static ISwitch GPSUpdateS[] = { {"Update", "", ISS_OFF, 0, 0}};
static ISwitch AltDecPecS[] = {{ "Enable", "", ISS_OFF, 0 ,0}, {"Disable", "", ISS_OFF, 0 ,0}};
static ISwitch AzRaPecS[] = {{ "Enable", "", ISS_OFF, 0, 0}, {"Disable", "", ISS_OFF, 0 ,0}};
@@ -42,7 +42,7 @@ static ISwitch AzRaBackSlashS[] = {{ "Activate", "", ISS_OFF, 0, 0}};
static ISwitch OTAUpdateS[] = {{ "Update", "", ISS_OFF, 0, 0}};
static ISwitchVectorProperty GPSPowerSw = { mydev, "GPS Power", "", GPSGroup, IP_RW, ISR_1OFMANY, 0 , IPS_IDLE, GPSPowerS, NARRAY(GPSPowerS), "", 0};
-static ISwitchVectorProperty GPStqStatusSw = { mydev, "GPS tqStatus", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPStqStatusS, NARRAY(GPStqStatusS), "", 0};
+static ISwitchVectorProperty GPSStatusSw = { mydev, "GPS Status", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPSStatusS, NARRAY(GPSStatusS), "", 0};
static ISwitchVectorProperty GPSUpdateSw = { mydev, "GPS System", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPSUpdateS, NARRAY(GPSUpdateS), "", 0};
static ISwitchVectorProperty AltDecPecSw = { mydev, "Alt/Dec PEC", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AltDecPecS, NARRAY(AltDecPecS), "", 0};
static ISwitchVectorProperty AzRaPecSw = { mydev, "Az/Ra PEC", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AzRaPecS, NARRAY(AzRaPecS), "", 0};
@@ -59,7 +59,7 @@ void updateTemp(void * /*p*/);
void changeLX200GPSDeviceName(const char *newName)
{
strcpy(GPSPowerSw.device, newName);
- strcpy(GPStqStatusSw.device, newName );
+ strcpy(GPSStatusSw.device, newName );
strcpy(GPSUpdateSw.device, newName );
strcpy(AltDecPecSw.device, newName );
strcpy(AzRaPecSw.device,newName );
@@ -87,7 +87,7 @@ if (dev && strcmp (thisDevice, dev))
LX200_16::ISGetProperties(dev);
IDDefSwitch (&GPSPowerSw, NULL);
-IDDefSwitch (&GPStqStatusSw, NULL);
+IDDefSwitch (&GPSStatusSw, NULL);
IDDefSwitch (&GPSUpdateSw, NULL);
IDDefSwitch (&AltDecPecSw, NULL);
IDDefSwitch (&AzRaPecSw, NULL);
@@ -139,15 +139,15 @@ void LX200GPS::ISNewNumber (const char *dev, const char *name, double values[],
return;
}
- /* GPS tqStatus Update */
- if (!strcmp(name,GPStqStatusSw.name))
+ /* GPS Status Update */
+ if (!strcmp(name,GPSStatusSw.name))
{
- if (checkPower(&GPStqStatusSw))
+ if (checkPower(&GPSStatusSw))
return;
- IUResetSwitches(&GPStqStatusSw);
- IUUpdateSwitches(&GPStqStatusSw, states, names, n);
- index = getOnSwitch(&GPStqStatusSw);
+ IUResetSwitches(&GPSStatusSw);
+ IUUpdateSwitches(&GPSStatusSw, states, names, n);
+ index = getOnSwitch(&GPSStatusSw);
if (index == 0)
{
@@ -167,8 +167,8 @@ void LX200GPS::ISNewNumber (const char *dev, const char *name, double values[],
updateLocation();
}
- GPStqStatusSw.s = IPS_OK;
- IDSetSwitch (&GPStqStatusSw, "%s", msg);
+ GPSStatusSw.s = IPS_OK;
+ IDSetSwitch (&GPSStatusSw, "%s", msg);
return;
}
diff --git a/kstars/kstars/indi/sbigccd.cpp b/kstars/kstars/indi/sbigccd.cpp
index d5b03096..fb35cf59 100644
--- a/kstars/kstars/indi/sbigccd.cpp
+++ b/kstars/kstars/indi/sbigccd.cpp
@@ -326,7 +326,7 @@ void SBIGCam::ISStaticPoll(void *p)
void SBIGCam::ISPoll()
{
static int mtc=5;
- int readtqStatus=0;
+ int readStatus=0;
double ccdTemp (0);
switch (ExposeTimeNP.s)
@@ -340,8 +340,8 @@ void SBIGCam::ISPoll()
// JM: Here we check the status of the camera (whether it's still capturing an image or has finished that)
// ISPoll is called once per second. e.g. below for how we do this for Apogee Cameras
/*
- readtqStatus = cam->read_tqStatus();
- if (readtqStatus < 0)
+ readStatus = cam->read_Status();
+ if (readStatus < 0)
{
IDLog("Error in exposure!\n");
ExposeTimeNP.s = IPS_IDLE;
@@ -349,7 +349,7 @@ void SBIGCam::ISPoll()
IDSetNumber(&ExposeTimeNP, "Error in exposure procedure.");
return;
}
- else if (readtqStatus == Camera_tqStatus_ImageReady)
+ else if (readStatus == Camera_Status_ImageReady)
{
ExposeTimeN[0].value = 0;
ExposeTimeNP.s = IPS_OK;
diff --git a/kstars/kstars/indi/webcam/ccvt.h b/kstars/kstars/indi/webcam/ccvt.h
index f98a4bd2..c78f88a6 100644
--- a/kstars/kstars/indi/webcam/ccvt.h
+++ b/kstars/kstars/indi/webcam/ccvt.h
@@ -27,7 +27,7 @@
CCMAIL: kstars-devel@kde.org
Revision 1.3 2004/06/26 23:12:03 mutlaqja
- Hopefully this will fix compile issues on 64bit archs, and FreeBSD, among others. The assembly code is tqreplaced with a more portable, albeit slower C implementation. I imported the videodev.h header after cleaning it for user space.
+ Hopefully this will fix compile issues on 64bit archs, and FreeBSD, among others. The assembly code is replaced with a more portable, albeit slower C implementation. I imported the videodev.h header after cleaning it for user space.
Anyone who has problems compiling this, please report the problem to kstars-devel@kde.org
diff --git a/kstars/kstars/indi/webcam/ccvt_c2.c b/kstars/kstars/indi/webcam/ccvt_c2.c
index 1fb7bcbf..52ed276d 100644
--- a/kstars/kstars/indi/webcam/ccvt_c2.c
+++ b/kstars/kstars/indi/webcam/ccvt_c2.c
@@ -8,7 +8,7 @@
#include "ccvt_types.h"
/* by suitable definition of PIXTYPE, can do yuv to rgb or bgr, with or
-without word tqalignment */
+without word alignment */
/* This doesn't exactly earn a prize in a programming beauty contest. */
diff --git a/kstars/kstars/indi/webcam/ccvt_misc.c b/kstars/kstars/indi/webcam/ccvt_misc.c
index 0d907f8b..e774ca6d 100644
--- a/kstars/kstars/indi/webcam/ccvt_misc.c
+++ b/kstars/kstars/indi/webcam/ccvt_misc.c
@@ -19,7 +19,7 @@
reached at nemosoft@smcc.demon.nl.
*/
-/* This file tqcontains CCVT functions that aren't available in assembly yet
+/* This file contains CCVT functions that aren't available in assembly yet
(or are not worth programming)
*/
@@ -31,7 +31,7 @@
* CCMAIL: kstars-devel@kde.org
*
* Revision 1.1 2004/06/26 23:12:03 mutlaqja
- * Hopefully this will fix compile issues on 64bit archs, and FreeBSD, among others. The assembly code is tqreplaced with a more portable, albeit slower C implementation. I imported the videodev.h header after cleaning it for user space.
+ * Hopefully this will fix compile issues on 64bit archs, and FreeBSD, among others. The assembly code is replaced with a more portable, albeit slower C implementation. I imported the videodev.h header after cleaning it for user space.
*
* Anyone who has problems compiling this, please report the problem to kstars-devel@kde.org
*
diff --git a/kstars/kstars/indi/webcam/pwc-ioctl.h b/kstars/kstars/indi/webcam/pwc-ioctl.h
index d545eb76..9b650298 100644
--- a/kstars/kstars/indi/webcam/pwc-ioctl.h
+++ b/kstars/kstars/indi/webcam/pwc-ioctl.h
@@ -43,7 +43,7 @@
/* The frame rate is encoded in the video_window.flags parameter using
the upper 16 bits, since some flags are defined nowadays. The following
- defines provide a tqmask and shift to filter out this value.
+ defines provide a mask and shift to filter out this value.
In 'Snapshot' mode the camera freezes its automatic exposure and colour
balance controls.
diff --git a/kstars/kstars/indi/webcam/videodev.h b/kstars/kstars/indi/webcam/videodev.h
index eb0ac6cf..a5b0aec7 100644
--- a/kstars/kstars/indi/webcam/videodev.h
+++ b/kstars/kstars/indi/webcam/videodev.h
@@ -214,7 +214,7 @@ struct video_info
unsigned int picture_type; /* current picture type */
unsigned int temporal_reference; /* current temporal reference */
unsigned char user_data[256]; /* user data last found in compressed stream */
- /* user_data[0] tqcontains user data flags, user_data[1] has count */
+ /* user_data[0] contains user data flags, user_data[1] has count */
};
/* generic structure for setting playback modes */
diff --git a/kstars/kstars/indi/apogee/ApnCamera.cpp b/kstars/kstars/indi/apogee/ApnCamera.cpp
index 4ed8d8c6..4e8c1b00 100644
--- a/kstars/kstars/indi/apogee/ApnCamera.cpp
+++ b/kstars/kstars/indi/apogee/ApnCamera.cpp
@@ -45,7 +45,7 @@ bool CApnCamera::Expose( double Duration, bool Light )
unsigned short TotalVPixels;
- while ( read_ImagingtqStatus() != Apn_tqStatus_Flushing )
+ while ( read_ImagingStatus() != Apn_Status_Flushing )
{
Sleep( 20 );
}
@@ -128,7 +128,7 @@ bool CApnCamera::Expose( double Duration, bool Light )
PostRoiRows = 1;
}
- // Set up the tqgeometry for a full frame device
+ // Set up the geometry for a full frame device
if ( m_ApnSensorInfo->m_EnableSingleRowOffset )
{
PreRoiVBinning += PreRoiRows;
@@ -296,7 +296,7 @@ unsigned short CApnCamera::GetExposurePixelsV()
double CApnCamera::read_InputVoltage()
{
- UpdateGeneraltqStatus();
+ UpdateGeneralStatus();
return m_pvtInputVoltage;
}
@@ -329,7 +329,7 @@ unsigned short CApnCamera::read_FirmwareVersion()
bool CApnCamera::read_ShutterState()
{
- UpdateGeneraltqStatus();
+ UpdateGeneralStatus();
return m_pvtShutterState;
}
@@ -559,15 +559,15 @@ void CApnCamera::write_DataBits( Apn_Resolution BitResolution )
}
}
-Apn_tqStatus CApnCamera::read_ImagingtqStatus()
+Apn_Status CApnCamera::read_ImagingStatus()
{
bool Exposing, Active, Done, Flushing, WaitOnTrigger;
bool DataHalted, RamError;
- UpdateGeneraltqStatus();
+ UpdateGeneralStatus();
- // Update the ImagingtqStatus
+ // Update the ImagingStatus
Exposing = false;
Active = false;
Done = false;
@@ -576,65 +576,65 @@ Apn_tqStatus CApnCamera::read_ImagingtqStatus()
DataHalted = false;
RamError = false;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_IMAGING_ACTIVE) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_IMAGING_ACTIVE) != 0 )
Active = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_IMAGE_EXPOSING) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_IMAGE_EXPOSING) != 0 )
Exposing = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_IMAGE_DONE) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_IMAGE_DONE) != 0 )
Done = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_FLUSHING) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_FLUSHING) != 0 )
Flushing = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_WAITING_TRIGGER) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_WAITING_TRIGGER) != 0 )
WaitOnTrigger = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_DATA_HALTED) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_DATA_HALTED) != 0 )
DataHalted = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_PATTERN_ERROR) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_PATTERN_ERROR) != 0 )
RamError = true;
if ( RamError )
{
- m_pvtImagingtqStatus = Apn_tqStatus_PatternError;
+ m_pvtImagingStatus = Apn_Status_PatternError;
}
else
{
if ( DataHalted )
{
- m_pvtImagingtqStatus = Apn_tqStatus_DataError;
+ m_pvtImagingStatus = Apn_Status_DataError;
}
else
{
if ( WaitOnTrigger )
{
- m_pvtImagingtqStatus = Apn_tqStatus_WaitingOnTrigger;
+ m_pvtImagingStatus = Apn_Status_WaitingOnTrigger;
}
else
{
if ( Done && m_pvtImageInProgress )
{
m_pvtImageReady = true;
- m_pvtImagingtqStatus = Apn_tqStatus_ImageReady;
+ m_pvtImagingStatus = Apn_Status_ImageReady;
}
else
{
if ( Active )
{
if ( Exposing )
- m_pvtImagingtqStatus = Apn_tqStatus_Exposing;
+ m_pvtImagingStatus = Apn_Status_Exposing;
else
- m_pvtImagingtqStatus = Apn_tqStatus_ImagingActive;
+ m_pvtImagingStatus = Apn_Status_ImagingActive;
}
else
{
if ( Flushing )
- m_pvtImagingtqStatus = Apn_tqStatus_Flushing;
+ m_pvtImagingStatus = Apn_Status_Flushing;
else
- m_pvtImagingtqStatus = Apn_tqStatus_Idle;
+ m_pvtImagingStatus = Apn_Status_Idle;
}
}
}
@@ -642,39 +642,39 @@ Apn_tqStatus CApnCamera::read_ImagingtqStatus()
}
/*
- switch( m_pvtImagingtqStatus )
+ switch( m_pvtImagingStatus )
{
- case Apn_tqStatus_DataError:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_DataError" );
+ case Apn_Status_DataError:
+ OutputDebugString( "ImagingStatus: Apn_Status_DataError" );
break;
- case Apn_tqStatus_PatternError:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_PatternError" );
+ case Apn_Status_PatternError:
+ OutputDebugString( "ImagingStatus: Apn_Status_PatternError" );
break;
- case Apn_tqStatus_Idle:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_Idle" );
+ case Apn_Status_Idle:
+ OutputDebugString( "ImagingStatus: Apn_Status_Idle" );
break;
- case Apn_tqStatus_Exposing:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_Exposing" );
+ case Apn_Status_Exposing:
+ OutputDebugString( "ImagingStatus: Apn_Status_Exposing" );
break;
- case Apn_tqStatus_ImagingActive:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_ImagingActive" );
+ case Apn_Status_ImagingActive:
+ OutputDebugString( "ImagingStatus: Apn_Status_ImagingActive" );
break;
- case Apn_tqStatus_ImageReady:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_ImageReady" );
+ case Apn_Status_ImageReady:
+ OutputDebugString( "ImagingStatus: Apn_Status_ImageReady" );
break;
- case Apn_tqStatus_Flushing:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_Flushing" );
+ case Apn_Status_Flushing:
+ OutputDebugString( "ImagingStatus: Apn_Status_Flushing" );
break;
- case Apn_tqStatus_WaitingOnTrigger:
- OutputDebugString( "ImagingtqStatus: Apn_tqStatus_WaitingOnTrigger" );
+ case Apn_Status_WaitingOnTrigger:
+ OutputDebugString( "ImagingStatus: Apn_Status_WaitingOnTrigger" );
break;
default:
- OutputDebugString( "ImagingtqStatus: UNDEFINED!!" );
+ OutputDebugString( "ImagingStatus: UNDEFINED!!" );
break;
}
*/
- return m_pvtImagingtqStatus;
+ return m_pvtImagingStatus;
}
Apn_LedMode CApnCamera::read_LedMode()
@@ -763,51 +763,51 @@ void CApnCamera::write_CoolerEnable( bool CoolerEnable )
m_pvtCoolerEnable = CoolerEnable;
}
-Apn_CoolertqStatus CApnCamera::read_CoolertqStatus()
+Apn_CoolerStatus CApnCamera::read_CoolerStatus()
{
bool CoolerAtTemp;
bool CoolerActive;
bool CoolerTempRevised;
- UpdateGeneraltqStatus();
+ UpdateGeneralStatus();
- // Update CoolertqStatus
+ // Update CoolerStatus
CoolerActive = false;
CoolerAtTemp = false;
CoolerTempRevised = false;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_TEMP_AT_TEMP) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_TEMP_AT_TEMP) != 0 )
CoolerAtTemp = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_TEMP_ACTIVE) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_TEMP_ACTIVE) != 0 )
CoolerActive = true;
- if ( (m_pvtqStatusReg & FPGA_BIT_STATUS_TEMP_REVISION) != 0 )
+ if ( (m_pvtStatusReg & FPGA_BIT_STATUS_TEMP_REVISION) != 0 )
CoolerTempRevised = true;
// Now derive our cooler state
if ( !CoolerActive )
{
- m_pvtCoolertqStatus = Apn_CoolertqStatus_Off;
+ m_pvtCoolerStatus = Apn_CoolerStatus_Off;
}
else
{
if ( CoolerTempRevised )
{
- m_pvtCoolertqStatus = Apn_CoolertqStatus_Revision;
+ m_pvtCoolerStatus = Apn_CoolerStatus_Revision;
}
else
{
if ( CoolerAtTemp )
- m_pvtCoolertqStatus = Apn_CoolertqStatus_AtSetPoint;
+ m_pvtCoolerStatus = Apn_CoolerStatus_AtSetPoint;
else
- m_pvtCoolertqStatus = Apn_CoolertqStatus_RampingToSetPoint;
+ m_pvtCoolerStatus = Apn_CoolerStatus_RampingToSetPoint;
}
}
- return m_pvtCoolertqStatus;
+ return m_pvtCoolerStatus;
}
double CApnCamera::read_CoolerSetPoint()
@@ -874,14 +874,14 @@ void CApnCamera::write_CoolerBackoffPoint( double BackoffPoint )
double CApnCamera::read_CoolerDrive()
{
- UpdateGeneraltqStatus();
+ UpdateGeneralStatus();
return m_pvtCoolerDrive;
}
double CApnCamera::read_TempCCD()
{
- // UpdateGeneraltqStatus();
+ // UpdateGeneralStatus();
unsigned short TempReg;
unsigned short TempAvg;
@@ -910,7 +910,7 @@ double CApnCamera::read_TempCCD()
double CApnCamera::read_TempHeatsink()
{
- // UpdateGeneraltqStatus();
+ // UpdateGeneralStatus();
unsigned short TempReg;
unsigned short TempAvg;
@@ -1782,8 +1782,8 @@ long CApnCamera::InitDefaults()
Write( FPGA_REG_TEMP_RAMP_DOWN_A, m_ApnSensorInfo->m_TempRampRateOne );
Write( FPGA_REG_TEMP_RAMP_DOWN_B, m_ApnSensorInfo->m_TempRampRateTwo );
// the collor code not only determines the m_pvtCoolerEnable state, but
- // also implicitly calls UpdateGeneraltqStatus() as part of read_CoolertqStatus()
- if ( read_CoolertqStatus() == Apn_CoolertqStatus_Off )
+ // also implicitly calls UpdateGeneralStatus() as part of read_CoolerStatus()
+ if ( read_CoolerStatus() == Apn_CoolerStatus_Off )
m_pvtCoolerEnable = false;
else
m_pvtCoolerEnable = true;
@@ -1827,9 +1827,9 @@ long CApnCamera::WriteTwelveBitOffset()
return 0;
}
-void CApnCamera::UpdateGeneraltqStatus()
+void CApnCamera::UpdateGeneralStatus()
{
- unsigned short tqStatusReg;
+ unsigned short StatusReg;
unsigned short HeatsinkTempReg;
unsigned short CcdTempReg;
unsigned short CoolerDriveReg;
@@ -1840,7 +1840,7 @@ void CApnCamera::UpdateGeneraltqStatus()
// Read the general status register of the device
- QuerytqStatusRegs( tqStatusReg,
+ QueryStatusRegs( StatusReg,
HeatsinkTempReg,
CcdTempReg,
CoolerDriveReg,
@@ -1848,7 +1848,7 @@ void CApnCamera::UpdateGeneraltqStatus()
TdiCounterReg,
SequenceCounterReg );
- m_pvtqStatusReg = tqStatusReg;
+ m_pvtStatusReg = StatusReg;
HeatsinkTempReg &= FPGA_MASK_TEMP_PARAMS;
CcdTempReg &= FPGA_MASK_TEMP_PARAMS;
@@ -1869,7 +1869,7 @@ void CApnCamera::UpdateGeneraltqStatus()
m_pvtInputVoltage = VoltageReg * APN_VOLTAGE_RESOLUTION;
// Update ShutterState
- m_pvtShutterState = ( (m_pvtqStatusReg & FPGA_BIT_STATUS_SHUTTER_OPEN) != 0 );
+ m_pvtShutterState = ( (m_pvtStatusReg & FPGA_BIT_STATUS_SHUTTER_OPEN) != 0 );
}
diff --git a/kstars/kstars/indi/apogee/CameraIO_Linux.cpp b/kstars/kstars/indi/apogee/CameraIO_Linux.cpp
index fcfd9070..67d217ec 100644
--- a/kstars/kstars/indi/apogee/CameraIO_Linux.cpp
+++ b/kstars/kstars/indi/apogee/CameraIO_Linux.cpp
@@ -56,8 +56,8 @@ CCameraIO::CCameraIO()
m_WaitingforLine = false;
m_WaitingforTrigger = false;
- m_tqStatus = Camera_tqStatus_Idle;
- m_CoolertqStatus = Camera_CoolertqStatus_Off;
+ m_Status = Camera_Status_Idle;
+ m_CoolerStatus = Camera_CoolerStatus_Off;
m_ExposureBinX = 0;
m_ExposureBinY = 0;
@@ -240,7 +240,7 @@ bool CCameraIO::FilterHome()
// Check for strobe
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( val & RegBit_GotTrigger )
{
// Cycle all the way around if it's on the first time
@@ -268,13 +268,13 @@ bool CCameraIO::FilterHome()
Sleep ( STEP_DELAY );
val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( val & RegBit_GotTrigger )
{
Sleep ( 10 );
val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( val & RegBit_GotTrigger )
{
// Restore normal priority
@@ -502,12 +502,12 @@ bool CCameraIO::GetImage( unsigned short* pImageData, short& xSize, short& ySize
int i;
unsigned short BIC = m_ExposureBIC + m_ExposureStartX;
// Update internal variables in case application did not poll read_tqStatus
m_WaitingforTrigger = false;
m_WaitingforLine = false;
if ( m_WaitingforImage )
- { // In case application did not poll read_tqStatus
+ { // In case application did not poll read_Status
m_WaitingforImage = false;
/////////////////////////////////////
@@ -516,7 +516,7 @@ bool CCameraIO::GetImage( unsigned short* pImageData, short& xSize, short& ySize
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_FrameDone ) != 0 ) break;
if ( clock() > StopTime ) return false; // Timed out
@@ -553,7 +553,7 @@ bool CCameraIO::GetImage( unsigned short* pImageData, short& xSize, short& ySize
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break; // Line done
if ( clock() > StopTime )
@@ -611,7 +611,7 @@ bool CCameraIO::GetImage( unsigned short* pImageData, short& xSize, short& ySize
if ( m_HighPriority ) SetPriorityClass ( hProcess, Class );
}
-// UntqmaskIrqs();
+// UnmaskIrqs();
if ( ret )
{ // We were successfull
@@ -679,7 +679,7 @@ bool CCameraIO::GetLine( unsigned short* pLineData, short& xSize )
int i;
if ( m_WaitingforLine )
- { // In case application did not poll read_tqStatus
+ { // In case application did not poll read_Status
m_WaitingforLine = false;
/////////////////////////////////////
@@ -688,7 +688,7 @@ bool CCameraIO::GetLine( unsigned short* pLineData, short& xSize )
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_LineDone ) != 0 ) break; // Line done
if ( clock() > StopTime )
@@ -746,7 +746,7 @@ bool CCameraIO::GetLine( unsigned short* pLineData, short& xSize )
if ( m_HighPriority ) SetPriorityClass ( hProcess, Class );
}
-// UntqmaskIrqs();
+// UnmaskIrqs();
return ret;
}
@@ -763,11 +763,11 @@ bool CCameraIO::Snap( double Duration, bool Light, unsigned short* pImageData, s
if ( m_WaitingforTrigger )
{
- Camera_tqStatus stat;
+ Camera_Status stat;
while ( true )
{ // This will wait forever if no trigger happens
- stat = read_tqStatus();
- if ( stat == Camera_tqStatus_Exposing ) break;
+ stat = read_Status();
+ if ( stat == Camera_Status_Exposing ) break;
Sleep( 220 ); // dont bog down the CPU while polling
}
m_WaitingforTrigger = false;
@@ -778,8 +778,8 @@ bool CCameraIO::Snap( double Duration, bool Light, unsigned short* pImageData, s
clock_t StopTime = clock() + long( ( 1.2 * Duration + m_Timeout ) * CLOCKS_PER_SEC );
while ( true )
{
- Camera_tqStatus stat = read_tqStatus();
- if ( stat == Camera_tqStatus_ImageReady ) break;
+ Camera_Status stat = read_Status();
+ if ( stat == Camera_Status_ImageReady ) break;
if ( clock() > StopTime ) return false; // Timed out, no image available
Sleep( 220 ); // dont bog down the CPU while polling
@@ -791,43 +791,43 @@ bool CCameraIO::Snap( double Duration, bool Light, unsigned short* pImageData, s
////////////////////////////////////////////////////////////
// Camera Settings
-Camera_tqStatus CCameraIO::read_tqStatus()
+Camera_Status CCameraIO::read_Status()
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( val & RegBit_Exposing ) //11.0
{
ATLTRACE( "Exposing\r\n" );
m_WaitingforTrigger = false;
- m_tqStatus = Camera_tqStatus_Exposing;
+ m_Status = Camera_Status_Exposing;
}
else if ( m_WaitingforTrigger )
- m_tqStatus = Camera_tqStatus_Waiting;
+ m_Status = Camera_Status_Waiting;
else if ( m_WaitingforImage && ( val & RegBit_FrameDone ) ) //11.11
{
ATLTRACE( "ImageReady\r\n" );
m_WaitingforImage = false;
- m_tqStatus = Camera_tqStatus_ImageReady;
+ m_Status = Camera_Status_ImageReady;
}
else if ( m_WaitingforLine && ( val & RegBit_LineDone ) ) //11.1
{
ATLTRACE( "LineReady\r\n" );
m_WaitingforLine = false;
- m_tqStatus = Camera_tqStatus_LineReady;
+ m_Status = Camera_Status_LineReady;
}
else if ( m_WaitingforImage || m_WaitingforLine )
{
ATLTRACE( "Flushing\r\n" );
- m_tqStatus = Camera_tqStatus_Flushing;
+ m_Status = Camera_Status_Flushing;
}
else
- m_tqStatus = Camera_tqStatus_Idle;
+ m_Status = Camera_Status_Idle;
- return m_tqStatus;
+ return m_Status;
}
bool CCameraIO::read_Present()
@@ -839,13 +839,13 @@ bool CCameraIO::read_Present()
bool FailedLoopback = false;
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( !( val & RegBit_LoopbackTest ) ) FailedLoopback = true;
m_RegShadow[ Reg_BICCounter ] &= ~RegBit_LoopbackTest; // clear bit to 0
Write( Reg_BICCounter, m_RegShadow[ Reg_BICCounter ] );
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( val & RegBit_LoopbackTest ) FailedLoopback = true;
*/
@@ -884,7 +884,7 @@ bool CCameraIO::read_Present()
bool CCameraIO::read_Shutter()
{
unsigned short regval = 0;
- Read( Reg_tqStatus, regval );
+ Read( Reg_Status, regval );
if ( !( regval & RegBit_Exposing ) )
{ // We are not exposing, but might have finnshed an exposure
// and have not called GetImage yet, so update our internal variable
@@ -917,7 +917,7 @@ void CCameraIO::write_ForceShutterOpen( bool val )
m_RegShadow[ Reg_Command ] &= ~RegBit_ShutterOverride; // clear bit to 0
unsigned short regval = 0;
- Read( Reg_tqStatus, regval );
+ Read( Reg_Status, regval );
if ( ( regval & RegBit_Exposing ) )
{
// Shutter will remain open if a Light frame is being taken
@@ -1076,7 +1076,7 @@ void CCameraIO::write_CoolerSetPoint( double val )
Write( Reg_TempSetPoint, m_RegShadow[ Reg_TempSetPoint ] );
}
-Camera_CoolertqStatus CCameraIO::read_CoolertqStatus()
+Camera_CoolerStatus CCameraIO::read_CoolerStatus()
{
unsigned short val = 0;
Read( Reg_CommandReadback, val );
@@ -1084,34 +1084,34 @@ Camera_CoolertqStatus CCameraIO::read_CoolertqStatus()
if ( val & RegBit_CoolerEnable ) //12.15
{
unsigned short val2 = 0;
- Read( Reg_tqStatus, val2 );
+ Read( Reg_Status, val2 );
if ( val & RegBit_CoolerShutdown ) //12.8
{
if ( val2 & RegBit_ShutdownComplete ) //11.6
- m_CoolertqStatus = Camera_CoolertqStatus_AtAmbient;
+ m_CoolerStatus = Camera_CoolerStatus_AtAmbient;
else
- m_CoolertqStatus = Camera_CoolertqStatus_RampingToAmbient;
+ m_CoolerStatus = Camera_CoolerStatus_RampingToAmbient;
}
else
{
if ( val2 & RegBit_TempAtMax ) //11.5
- m_CoolertqStatus = Camera_CoolertqStatus_AtMax;
+ m_CoolerStatus = Camera_CoolerStatus_AtMax;
else if ( val2 & RegBit_TempAtMin ) //11.4
- m_CoolertqStatus = Camera_CoolertqStatus_AtMin;
+ m_CoolerStatus = Camera_CoolerStatus_AtMin;
else if ( val2 & RegBit_TempAtSetPoint ) //11.7
- m_CoolertqStatus = Camera_CoolertqStatus_AtSetPoint;
+ m_CoolerStatus = Camera_CoolerStatus_AtSetPoint;
// Check against last known cooler status
- else if ( m_CoolertqStatus == Camera_CoolertqStatus_AtSetPoint )
- m_CoolertqStatus = Camera_CoolertqStatus_Correcting;
+ else if ( m_CoolerStatus == Camera_CoolerStatus_AtSetPoint )
+ m_CoolerStatus = Camera_CoolerStatus_Correcting;
else
- m_CoolertqStatus = Camera_CoolertqStatus_RampingToSetPoint;
+ m_CoolerStatus = Camera_CoolerStatus_RampingToSetPoint;
}
}
else
- m_CoolertqStatus = Camera_CoolertqStatus_Off;
+ m_CoolerStatus = Camera_CoolerStatus_Off;
- return m_CoolertqStatus;
+ return m_CoolerStatus;
}
Camera_CoolerMode CCameraIO::read_CoolerMode()
@@ -1319,7 +1319,7 @@ void CCameraIO::Flush( short Rows )
while ( true )
{
unsigned short val = 0;
- Read( Reg_tqStatus, val );
+ Read( Reg_Status, val );
if ( ( val & RegBit_FrameDone ) != 0 ) break;
if ( clock() > StopTime ) break; // Timed out
@@ -502,12 +502,12 @@ bool CCameraIO::GetImage( unsigned short* pImageData, short& xSize, short& ySize
int i;
unsigned short BIC = m_ExposureBIC + m_ExposureStartX;
- // Update internal variables in case application did not poll read_tqStatus
+ // Update internal variables in case application did not poll read_Status
m_WaitingforTrigger = false;
m_WaitingforLine = false;
diff --git a/kstars/kstars/indi/apogee/Camera_Example.cpp b/kstars/kstars/indi/apogee/Camera_Example.cpp
index 52a95f43..f1f64121 100644
--- a/kstars/kstars/indi/apogee/Camera_Example.cpp
+++ b/kstars/kstars/indi/apogee/Camera_Example.cpp
@@ -295,9 +295,9 @@ long config_load( char* cfgname, short BaseAddress, short RegOffset )
}
/////////////////////////////////////////////////////////////////////////////////
- // Necessary tqgeometry settings
+ // Necessary geometry settings
- if (CfgGet (inifp, "tqgeometry", "rows", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "rows", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXTOTALROWS ) cam->m_Rows = val;
@@ -310,7 +310,7 @@ long config_load( char* cfgname, short BaseAddress, short RegOffset )
return CCD_OPEN_CFGDATA; // rows MUST be defined
}
- if (CfgGet (inifp, "tqgeometry", "columns", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "columns", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXTOTALCOLUMNS ) cam->m_Columns = val;
@@ -490,31 +490,31 @@ long config_load( char* cfgname, short BaseAddress, short RegOffset )
/////////////////////////////////////////////////////////////////////////////////
// Geometry
- if (CfgGet (inifp, "tqgeometry", "bic", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "bic", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXCOLUMNS ) cam->m_BIC = val;
}
- if (CfgGet (inifp, "tqgeometry", "bir", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "bir", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXROWS ) cam->m_BIR = val;
}
- if (CfgGet (inifp, "tqgeometry", "skipc", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "skipc", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 0 && val <= MAXCOLUMNS ) cam->m_SkipC = val;
}
- if (CfgGet (inifp, "tqgeometry", "skipr", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "skipr", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 0 && val <= MAXROWS ) cam->m_SkipR = val;
}
- if (CfgGet (inifp, "tqgeometry", "imgcols", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "imgcols", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXTOTALCOLUMNS ) cam->m_ImgColumns = val;
@@ -522,7 +522,7 @@ long config_load( char* cfgname, short BaseAddress, short RegOffset )
else
cam->m_ImgColumns = cam->m_Columns - cam->m_BIC - cam->m_SkipC;
- if (CfgGet (inifp, "tqgeometry", "imgrows", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "imgrows", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXTOTALROWS ) cam->m_ImgRows = val;
@@ -530,13 +530,13 @@ long config_load( char* cfgname, short BaseAddress, short RegOffset )
else
cam->m_ImgRows = cam->m_Rows - cam->m_BIR - cam->m_SkipR;
- if (CfgGet (inifp, "tqgeometry", "hflush", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "hflush", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXHBIN ) cam->m_HFlush = val;
}
- if (CfgGet (inifp, "tqgeometry", "vflush", retbuf, sizeof(retbuf), &plen))
+ if (CfgGet (inifp, "geometry", "vflush", retbuf, sizeof(retbuf), &plen))
{
short val = hextoi(retbuf);
if ( val >= 1 && val <= MAXVBIN ) cam->m_VFlush = val;